@@ -5,8 +5,7 @@ from typing import Any, Dict, Optional
 
 import requests
 
-from . import api, exceptions
-from .version import __version__
+from . import __version__, api, exceptions
 
 log = logging.getLogger(__name__)
 
