@@ -12,14 +12,10 @@ from pathlib import Path
 from types import ModuleType
 from typing import TYPE_CHECKING, Any, Dict, Optional
 
-if sys.version_info[:2] >= (3, 8):  # pragma: nocover
-    from importlib.metadata import version as importlib_metadata_version
-else:  # pragma: nocover
-    # Python 3.7 doesn't have this.
-    from importlib_metadata import version as importlib_metadata_version
-
 import typer
 
+from . import __version__
+
 
 def lazy_import(name: str) -> ModuleType:
     """
@@ -604,7 +600,7 @@ def version() -> None:
     """
     Returns the installed version.
     """
-    typer.echo(importlib_metadata_version(__package__))
+    typer.echo(__version__)
 
 
 @cli.command()
